@@ -7,7 +7,7 @@
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -550,11 +550,10 @@ void update_spline(F_spline *spline)
 void fix_fillstyle(void *obj)
 {
     F_line *object = obj;
-    if (object->fill_color == BLACK || object->fill_color == DEFAULT ||
-	object->fill_color == DEFAULT) {
-	    if (object->fill_style >= NUMSHADEPATS &&
+    if (object->fill_color == BLACK || object->fill_color == DEFAULT) {
+	if (object->fill_style >= NUMSHADEPATS &&
 		object->fill_style < NUMSHADEPATS+NUMTINTPATS)
-			object->fill_style = UNFILLED;
+	    object->fill_style = UNFILLED;
     }
     /* a little sanity check */
     if (object->fill_style < DEFAULT)
