@@ -6,7 +6,7 @@
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -109,12 +109,15 @@ emptyfigure_msg(char *msg)
 int
 change_directory(char *path)
 {
-    if (path == NULL || *path == '\0')
+    static char	cwd[PATH_MAX];
+
+    if (!strcmp(path, cwd) || path == NULL || *path == '\0')
 	return 0;
     if (chdir(path) == -1) {
 	file_msg("Can't go to directory %s, : %s", path, strerror(errno));
 	return 1;
     }
+    strcpy(cwd, path);
     return 0;
 }
 
