@@ -1,14 +1,15 @@
 /*
  * FIG : Facility for Interactive Generation of figures
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
- * Parts Copyright (c) 1989-2007 by Brian V. Smith
+ * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
+ * Parts Copyright (c) 2016-2019 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -239,7 +240,7 @@ static XtResource application_resources[] = {
     {"rulerthick", "RulerThick", XtRInt, sizeof(int),
       XtOffset(appresPtr, rulerthick), XtRImmediate, (caddr_t) 0},
     {"image_editor", "ImageEditor", XtRString, sizeof(char *),
-      XtOffset(appresPtr, image_editor), XtRString, (caddr_t) "xv"},
+      XtOffset(appresPtr, image_editor), XtRString, (caddr_t) "xdg-open"},
     {"magnification", "Magnification", XtRFloat, sizeof(float),
       XtOffset(appresPtr, magnification), XtRFloat, (caddr_t) & F100},
     {"paper_size", "Papersize", XtRString, sizeof(char *),
@@ -271,9 +272,9 @@ static XtResource application_resources[] = {
     {"pageborder", "Color",   XtRString, sizeof(char *),
       XtOffset(appresPtr, pageborder), XtRString, (caddr_t) "lightblue"},
     {"browser", "Browser", XtRString, sizeof(char *),
-      XtOffset(appresPtr, browser), XtRString, (caddr_t) "firefox"},
+      XtOffset(appresPtr, browser), XtRString, (caddr_t) "xdg-open %f"},
     {"pdfviewer", "Viewer", XtRString, sizeof(char *),
-      XtOffset(appresPtr, pdf_viewer), XtRString, (caddr_t) "acroread"},
+      XtOffset(appresPtr, pdf_viewer), XtRString, (caddr_t) "xdg-open %f"},
     {"spinner_delay", "spinnerDelay",   XtRInt, sizeof(int),
       XtOffset(appresPtr, spinner_delay), XtRImmediate, (caddr_t) 500},
     {"spinner_rate", "spinnerRate",   XtRInt, sizeof(int),
@@ -631,7 +632,8 @@ struct  geom   geom;
 int setup_visual (int *argc_p, char **argv, Arg *args);
 void get_pointer_mapping (void);
 
-void main(int argc, char **argv)
+int
+main(int argc, char **argv)
 {
     Widget	    children[NCHILDREN];
     XEvent	    event;
@@ -640,7 +642,6 @@ void main(int argc, char **argv)
     XWMHints	   *wmhints;
     int		    i,j;
     XColor	    dumcolor;
-    char	    version[30];
     char	   *dval;
     char	    tmpstr[PATH_MAX];
 
@@ -651,9 +652,6 @@ void main(int argc, char **argv)
     /* generate version string for various uses */
     sprintf(xfig_version, "Xfig %s", PACKAGE_VERSION);
 
-    /* ratio of Fig units to display resolution (80ppi) */
-    ZOOM_FACTOR = PIX_PER_INCH/DISPLAY_PIX_PER_INCH;
-
     /* make a copy of the version */
     (void) strcpy(tool_name, xfig_version);
     (void) sprintf(file_header, "#FIG %s", PROTOCOL_VERSION);
@@ -789,6 +787,9 @@ void main(int argc, char **argv)
     screen_wd = WidthOfScreen(XtScreen(tool));
     screen_ht = HeightOfScreen(XtScreen(tool));
 
+    /* ratio of Fig units to display resolution (80ppi) */
+    ZOOM_FACTOR = PIX_PER_INCH/DISPLAY_PIX_PER_INCH;
+
     /* get the FIG2DEV_DIR environment variable (if any is set) for the path
        to fig2dev, in case the user wants one not in the normal search path */
     if ((fig2dev_path = getenv("FIG2DEV_DIR"))==NULL)
@@ -1188,7 +1189,7 @@ void main(int argc, char **argv)
 	XtManageChild(mode_panel);
 
 	/* move the depth manager to its right */
-	FirstArg(XtNfromHoriz, mode_panel)
+	FirstArg(XtNfromHoriz, mode_panel);
 	SetValues(layer_form);
 
     }
@@ -1314,17 +1315,15 @@ void main(int argc, char **argv)
     process_pending();
 
     /* now that everything is up, check the version number in the app-defaults */
-    sprintf(version,"%s", PACKAGE_VERSION);
-    if (!appres.version || strcasecmp(appres.version,version) < 0) {
-	if (!appres.version) {
-	    file_msg("Either you have a very old app-defaults file installed (Fig),");
-	    file_msg("or there is none installed at all.");
-	} else {
-	    file_msg("The app-defaults file (version: %s) is older", appres.version);
-	    file_msg("    than this version of xfig (%s).",version);
-	}
+    /*
+     * The app-defaults file did not change for ages, there are sane
+     * defaults provided, hence announcing an old version is more disruptive
+     * to the user than simply continuing with an old version.
+     */
+    if (!appres.version) {
+	file_msg("Either you have a very old app-defaults file installed (Fig),");
+	file_msg("or there is none installed at all.");
 	file_msg("You should install the correct version or you may lose some features.");
-	file_msg("This may be done with \"make install\" in the xfig source directory.");
 	beep();
 	beep();
     }
@@ -1832,7 +1831,7 @@ set_xpm_icon(void)
 {
     xpm_icon_status = -1;
 
-#ifdef USE_XPM_ICON
+#ifdef USE_XPM
     /********************************************/
     /* use the XPM color icon for color display */
     /********************************************/
@@ -1867,12 +1866,12 @@ set_xpm_icon(void)
 				figure_ic.width, figure_ic.height);
 	}
     } else {
-#endif /* USE_XPM_ICON */
+#endif /* USE_XPM */
 	fig_icon = XCreateBitmapFromData(tool_d, tool_w, (char *) figure_ic.bits,
 				figure_ic.width, figure_ic.height);
-#ifdef USE_XPM_ICON
+#ifdef USE_XPM
     }
-#endif /* USE_XPM_ICON */
+#endif /* USE_XPM */
 
     FirstArg(XtNtitle, tool_name);
     NextArg(XtNiconPixmap, fig_icon);
